/*
 * Example for DC Motor 4 click
 *
 * Date         Apr 2017
 * Author       Djordje Rosic
 *
 * Test configuration PIC32 :
 *  MCU           :        P32MX795F512L
 *  Dev. Board    :        EasyPIC Fusion v7
 *  SW            :        mikroC PRO for PIC32 v3.6.1
 *
 * Description :
 *
 * This example shows basic controls of DC motor using DC motor 4 click.
 * It shows forward and reverse movement, and high and low rotation speed.
 *
 ******************************************************************************/

#include <stdint.h>

uint16_t pwmPeriod;
sbit DIR_PIN at LATB8_bit;
sbit DIR_PIN_DIR at TRISB8_bit;
/*
 * System Initialization
 */
void systemInit()
{
    DIR_PIN_DIR = 0;
    pwmPeriod = PWM_Init(1000, 1, 1, 2);  // Set PWM frequency/period (according to the DC motor characteristics)
    PWM_Start(1);
}

void main()
{

    systemInit();

    while (1)
    {
        //Forward
        DIR_PIN = 0;
      
        //Forward fast
        PWM_Set_Duty(pwmPeriod,1);
        PWM_Start(1);
        Delay_ms (3000);
        
        //Forward slow
        PWM_Set_Duty(pwmPeriod/2, 1);
        PWM_Start(1);
        Delay_ms (3000);
        
        //Reverse
        DIR_PIN = 1;
        
        //Reverse fast
        PWM_Set_Duty(pwmPeriod, 1);
        PWM_Start(1);
        Delay_ms (3000);
       
        //Reverse slow
        PWM_Set_Duty(pwmPeriod/2, 1);
        PWM_Start(1);
        Delay_ms (3000);
    }
}
/************************************************************ END OF FILE *****/